// Author: Hugo Pointcheval
// Email: git@pcl.ovh
// -----
// File: router.dart
// Created Date: 19/08/2022 11:52:22
// Last Modified: 19/08/2022 16:39:07
// -----
// Copyright (c) 2022

import 'package:example_router/presentation/features/home/home_page.dart';
import 'package:example_router/presentation/features/sign_in/sign_in_page.dart';
import 'package:example_router/presentation/features/sign_up/sign_up_page.dart';
import 'package:example_router/presentation/features/sub/sub_page.dart';
import 'package:example_router/presentation/features/welcome/welcome_page.dart';
import 'package:flutter/cupertino.dart';
import 'package:go_router/go_router.dart';

class AppRouter {
  /// Default transition for all pages
  static Page<void> defaultTransition(
    BuildContext context,
    GoRouterState state,
    Widget child,
  ) =>
      CupertinoPage<void>(
        key: state.pageKey,
        child: child,
      );

  static final publicRoutes = ['/', '/sign_in', '/sign_up'];

  static final List<GoRoute> routes = [
    GoRoute(
      path: '/',
      name: WelcomePage.pageName,
      pageBuilder: (context, state) => defaultTransition(
        context,
        state,
        const WelcomePage(),
      ),
    ),
    GoRoute(
      path: '/sign_in',
      name: SignInPage.pageName,
      pageBuilder: (context, state) => defaultTransition(
        context,
        state,
        const SignInPage(),
      ),
    ),
    GoRoute(
      path: '/sign_up',
      name: SignUpPage.pageName,
      pageBuilder: (context, state) => defaultTransition(
        context,
        state,
        const SignUpPage(),
      ),
    ),
    GoRoute(
      path: '/home',
      name: HomePage.pageName,
      pageBuilder: (context, state) => defaultTransition(
        context,
        state,
        const HomePage(),
      ),
    ),
    GoRoute(
      path: '/home/sub',
      name: SubPage.pageName,
      pageBuilder: (context, state) => defaultTransition(
        context,
        state,
        const SubPage(),
      ),
    ),
  ];
}
