// Copyright (C) 2022 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:wyatt_form_bloc/src/domain/entities/form_input_metadata.dart';
import 'package:wyatt_form_bloc/src/domain/repositories/form_repository.dart';
import 'package:wyatt_form_bloc/src/presentation/features/form_data/form_data_cubit.dart';

class InputBuilderTextController<Cubit extends FormDataCubit, S extends String?,
    Extra> extends StatelessWidget {
  InputBuilderTextController({
    required this.field,
    required this.builder,
    super.key,
  });

  final String field;

  final Widget Function(
    BuildContext context,
    Cubit cubit,
    FormDataState state,
    String field,
    bool inputValid,
    TextEditingController textEditingController,
    FormInputMetadata<Extra>? metadata,
  ) builder;

  final TextEditingController _controller = TextEditingController();

  @override
  Widget build(BuildContext context) {
    final formName = context.watch<Cubit>().formName;
    final value =
        context.read<FormRepository>().accessForm(formName).valueOf<S>(field);
    _controller
      ..text = value ?? ''
      ..selection = TextSelection.fromPosition(
        TextPosition(
          offset: _controller.text.length,
        ),
      );

    return BlocBuilder<Cubit, FormDataState>(
      builder: (context, state) {
        final cubit = context.read<Cubit>();
        final inputValid = state.form.validatorOf(field).valid;
        final metadata = state.form.metadataOf<Extra>(field);
        return builder.call(
          context,
          cubit,
          state,
          field,
          inputValid,
          _controller,
          metadata,
        );
      },
    );
  }
}
